@@ -1,7 +1,7 @@
 set.seed(1988)
 spatial.dim=2# number of spatial dimensions
-n=20**2  # number of observed locs
-m=20
+n=9  # number of observed locs
+m=4
 
 # simulate locations
 if(spatial.dim==1){
@@ -11,7 +11,7 @@ if(spatial.dim==1){
 }
 
 sig2=1; range=1; smooth=0.5
-me.var = 1e-8
+me.var = 1e-4
 covparms =c(sig2,range,smooth)
 covfun = function(locs1, locs2=NULL) {
   if(is.null(locs2)){
@@ -38,8 +38,19 @@ vecchia_loglik1 = vecchia_likelihood(z,V,covparms,nuggets,covmodel=Sig.sel)
 vecchia_loglik2 = vecchia_likelihood(z,V,covparms,nuggets,covmodel=covfun)
 vecchia_loglik3 = vecchia_likelihood(z,V,covparms,nuggets,covmodel='matern')
 
-test_that("cov. model can be passed as matern, matrix with only the required entries or R function", {
-  expect_equal(vecchia_loglik1-vecchia_loglik2, 0)
-  expect_equal(vecchia_loglik1-vecchia_loglik2, 0)
+test_that("likelihood is the same for all covariance argument types", {
   expect_equal(vecchia_loglik1-vecchia_loglik2, 0)
+  expect_equal(vecchia_loglik3-vecchia_loglik2, 0)
 })
+
+
+#### prediction ####
+vecchia_pred1 = vecchia_prediction(z, V, covparms, nuggets, covmodel = Sig.sel, return.values = 'mean')$mu.obs
+vecchia_pred2 = vecchia_prediction(z, V, covparms, nuggets, covmodel = covfun, return.values = 'mean')$mu.obs
+vecchia_pred3 = vecchia_prediction(z, V, covparms, nuggets, covmodel = 'matern', return.values = 'mean')$mu.obs
+
+
+test_that("prediction is the same for all covariance argument types", {
+  expect_equal(sum(abs(vecchia_pred1-vecchia_pred2)), 0)
+  expect_equal(sum(abs(vecchia_pred3-vecchia_pred2)), 0)
+})
\ No newline at end of file
